@@ -1,7 +1,7 @@
 from functools import wraps
-from django.conf import settings
 from django.http import HttpResponse
 from django.contrib.auth import authenticate, login
+from serrano.conf import settings
 
 
 def get_token(request):
@@ -16,8 +16,6 @@ def get_token(request):
 def check_auth(func):
     @wraps(func)
     def inner(self, request, *args, **kwargs):
-        auth_required = getattr(settings, 'SERRANO_AUTH_REQUIRED', False)
-
         user = getattr(request, 'user', None)
 
         # Attempt to authenticate if a token is present
@@ -26,7 +24,7 @@ def check_auth(func):
             user = authenticate(token=token)
             if user:
                 login(request, user)
-            elif auth_required:
+            elif settings.AUTH_REQUIRED:
                 return HttpResponse(status=401)
         return func(self, request, *args, **kwargs)
     return inner
