@@ -102,6 +102,10 @@ class FieldValues(FieldBase, PaginatorResource):
 
         path = reverse('serrano:field-values', kwargs={'pk': pk})
         links = self.get_page_links(request, path, page, extra=params)
+        links['parent'] = {
+            'href': request.build_absolute_uri(reverse('serrano:field',
+                                               kwargs={'pk': pk})),
+        }
 
         return {
             'values': page.object_list,
@@ -137,7 +141,8 @@ class FieldValues(FieldBase, PaginatorResource):
                       .values_list(field_name, flat=True))
 
         for datum in array:
-            datum['label'] = instance.get_label(datum['value'])
+            if 'label' not in datum:
+                datum['label'] = instance.get_label(datum['value'])
             datum['valid'] = datum['value'] in results
 
         usage.log('validate', instance=instance, request=request, data={
